Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrAlreadyExistingSignature = errors.New("The Artifact is already signed, will not overwrite existing signature")
var ErrManifestNotFound = errors.New("`manifest` not found. Corrupt Artifact?")
Functions ¶
func SignExisting ¶
Special fast-track to just sign, nothing else. This skips all the expensive and complicated repacking, and simply adds the manifest.sig file.
Types ¶
type WriteArtifactArgs ¶
type WriteArtifactArgs struct {
Format string
Version int
Devices []string
Name string
Updates *Updates
Scripts *artifact.Scripts
Depends *artifact.ArtifactDepends
Provides *artifact.ArtifactProvides
TypeInfoV3 *artifact.TypeInfoV3
MetaData map[string]interface{} // Generic JSON
AugmentTypeInfoV3 *artifact.TypeInfoV3
AugmentMetaData map[string]interface{} // Generic JSON
}
type Writer ¶
type Writer struct {
// contains filtered or unexported fields
}
Writer provides on the fly writing of artifacts metadata file used by the Mender client and the server.
func NewWriterSigned ¶
func (*Writer) WriteArtifact ¶
func (aw *Writer) WriteArtifact(args *WriteArtifactArgs) (err error)
Click to show internal directories.
Click to hide internal directories.